pub

# XMLRésuméLibrary: User Guide

province | Element Reference | pubDate

## Name

pub — A work published by the résumé “owner”

## Synopsis

### Content Model

    (para|(artTitle|bookTitle|author|date|pubDate|publisher|pageNums|url))*

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `pub` element contains elements that describe a work (like an article, a book, a poem, or a scholarly paper) that was published by the person the résumé describes.

### Parents

`pub` may be contained in these elements: `pubs`

### Attributes

`id`

  A string used to uniquely identify a publication. The publication may then be referred to by this identifier.

## See Also

`citation`.

## Examples

Example 4. Book with multiple authors

    <pub>
      <bookTitle>Foundations of Computer Science, C Edition</bookTitle>
      <author>Alfred V. Aho</author>
      <author>Jeffrey D. Ullman</author>
      <pubDate>
        <year>1995</year>
      </pubDate>
      <publisher>Computer Science Press, New York</publisher>
    </pub>

Example 5. Magazine article

    <pub>
      <artTitle>Low-Fat Philly Cheese Steaks</bookTitle>
      <bookTitle>Healthy Cooking</bookTitle>
      <author>Joe Sixpack</author>
      <pubDate>
        <month>June</month>
        <year>1999</year>
      </pubDate>
      <publisher>Healthy Publishing Group</publisher>
    </pub>

province | Element Reference | pubDate